@@ -196,7 +196,6 @@ def get_resouces(stack_name: str):
 def create_stack(stack_name: str, cfn_url: str, param_list: list,
                 disable_rollback: bool,
                 delete_stack: bool,
-                delete_stack_when_failure: bool,
                 role_arn: str
     ):
     client = boto3.client('cloudformation')
@@ -228,19 +227,17 @@ def create_stack(stack_name: str, cfn_url: str, param_list: list,
         )
     stack_id = response['StackId']
     logger.info("Creating to stack... : " + stack_name)
-    waiter = client.get_waiter('stack_create_complete')
-    waiter.wait(StackName=stack_name) # スタック完了まで待つ
-    resources = get_resouces(stack_name)
-    delete = False
+    try:
+        waiter = client.get_waiter('stack_create_complete')
+        waiter.wait(StackName=stack_name) # スタック完了まで待つ
+        resources = get_resouces(stack_name)
+    except Exception as e:
+        logger.warning(e)
     if view_resources(resources):
         logger.info("Creation to stack completed successfully!! : {}".format(stack_name))
-        if delete_stack:
-            delete = True
     else:
         logger.info("Attempted to create but failed... : {}".format(stack_name))
-        if delete_stack_when_failure or delete_stack:
-            delete = True
-    if delete:
+    if delete_stack:
         if role_arn != None:
             response = client.delete_stack(
                 StackName=stack_name,
@@ -325,35 +322,47 @@ def create_change_set(stack_name: str, cfn_url: str, param_list: list,
             ChangeSetName=change_set_name,
             IncludeNestedStacks=True
         )
+    stack_id = response['StackId']
     logger.info("Creating to change set... : " + change_set_name)
-    waiter = client.get_waiter('change_set_create_complete')
-    waiter.wait(
-        ChangeSetName=change_set_name,
-        StackName=stack_name
-    )
-    logger.info("Creation to change set completed successfully!! : {}".format(change_set_name))
+    try:
+        waiter = client.get_waiter('change_set_create_complete')
+        waiter.wait(
+            ChangeSetName=change_set_name,
+            StackName=stack_name
+        )
+        logger.info("Creation to change set completed successfully!! : {}".format(change_set_name))
+    except Exception as e:
+        logger.warning(e)
+        
     response = client.describe_change_set(
         ChangeSetName=change_set_name,
         StackName=stack_name
     )
-    stack_id = response['StackId']
-    if len(response['Changes']) == 0:
-        logger.info("Nothing differents from the current.")
+    if response['Status'] == 'CREATE_COMPLETE':
+        logger.info("Creation to change set completed successfully!! : {}".format(change_set_name))
+        if 'StatusReason' in response:
+            logger.info('Reason: ' + response['StatusReason'])
+        changes = get_changes(stack_name, change_set_name)
+        if len(changes) == 0:
+            logger.info("Nothing differents from the current.")
+        else:
+            view_changes(changes)
+            if change_set_force_deploy:
+                logger.info("Execute to change set: " + change_set_name)
+                response = client.execute_change_set(
+                    ChangeSetName=change_set_name,
+                    StackName=stack_name
+                )
+                logger.info("Executing change set...")
+                waiter = client.get_waiter('stack_update_complete')
+                waiter.wait(
+                    StackName=stack_name
+                )
+                logger.info("Execution to change set completed successfully!! : {}".format(change_set_name))
     else:
-        view_changes(response['Changes'])
-        if change_set_force_deploy:
-            logger.info("Execute to change set: " + change_set_name)
-            response = client.execute_change_set(
-                ChangeSetName=change_set_name,
-                StackName=stack_name
-            )
-            logger.info("Executing change set...")
-            waiter = client.get_waiter('stack_update_complete')
-            waiter.wait(
-                StackName=stack_name
-            )
-            logger.info("Execution to change set completed successfully!! : {}".format(change_set_name))
-    logger.info("Creation to change set completed successfully!! : {}".format(change_set_name))
+        logger.info("Attempted to create but failed... : {}".format(change_set_name))
+        if 'StatusReason' in response:
+            logger.info('Reason: ' + response['StatusReason'])
     return stack_id
 
 def view_param(param_list: list):
@@ -374,7 +383,6 @@ def view_param(param_list: list):
 def request_stack(stack_name: str, cfn_url: str, param_list: list,
                 disable_rollback: bool,
                 delete_stack: bool,
-                delete_stack_when_failure: bool,
                 role_arn: str,
                 change_set_force_deploy: bool
     ):
@@ -401,7 +409,7 @@ def request_stack(stack_name: str, cfn_url: str, param_list: list,
         logger.debug(e)
         pass
     if not stack_exists:
-        stack_id = create_stack(stack_name, cfn_url, param_list, disable_rollback, delete_stack, delete_stack_when_failure, role_arn)
+        stack_id = create_stack(stack_name, cfn_url, param_list, disable_rollback, delete_stack, role_arn)
     else:
         stack_id = create_change_set(stack_name, cfn_url, param_list, role_arn, change_set_force_deploy)
         
@@ -465,12 +473,6 @@ def main():
         dest="delete_stack",
         help="After creating a stack, the stack is deleted regardless of success or failure."
     )
-    parser.add_argument(
-        "-del-fail", "--delete-stack-when-failure",
-        action="store_true",
-        dest="delete_stack_when_failure",
-        help="If stack creation fails, the stack is deleted."
-    )
     parser.add_argument(
         "-v", "--version",
         action='version',
@@ -500,7 +502,7 @@ def main():
         cfn_url, bucket_name = upload_cfn(args.input_path)
     try:
         param = generate_parameter(args.param, args.s3_bucket_url_parameter_key_name, bucket_name)
-        request_stack(args.stack_name, cfn_url, param, args.disable_rollback, args.delete_stack, args.delete_stack_when_failure, args.role_arn, args.change_set_force_deploy)
+        request_stack(args.stack_name, cfn_url, param, args.disable_rollback, args.delete_stack, args.role_arn, args.change_set_force_deploy)
     except Exception as e:
         logger.error(e)
         logger.error('Fail to create or update stack')
